import matplotlib.pyplot as plt
from astropy.coordinates import uniform_spherical_random_surface, golden_spiral_grid

fig, axes = plt.subplots(1, 2, figsize=(10, 6),
                         subplot_kw=dict(projection='3d'),
                         constrained_layout=True)

for func, ax in zip([uniform_spherical_random_surface,
                     golden_spiral_grid], axes):
    pts = func(size=128)

    xyz = pts.to_cartesian().xyz
    ax.plot(*xyz, ls='none')

    ax.set(xlim=(-1, 1),
        ylim=(-1, 1),
        zlim=(-1, 1),
        xlabel='$x$',
        ylabel='$y$',
        zlabel='$z$')
    ax.set_title(func.__name__, fontsize=14)

fig.suptitle('128 points', fontsize=18)